# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ParentalStatusTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ParentalStatusTypeValue = typing___NewType("ParentalStatusTypeValue", builtin___int)
    type___ParentalStatusTypeValue = ParentalStatusTypeValue
    ParentalStatusType: _ParentalStatusType
    class _ParentalStatusType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ParentalStatusTypeEnum.ParentalStatusTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 0)
        UNKNOWN = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 1)
        PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 300)
        NOT_A_PARENT = typing___cast(
            ParentalStatusTypeEnum.ParentalStatusTypeValue, 301
        )
        UNDETERMINED = typing___cast(
            ParentalStatusTypeEnum.ParentalStatusTypeValue, 302
        )
    UNSPECIFIED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 0)
    UNKNOWN = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 1)
    PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 300)
    NOT_A_PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 301)
    UNDETERMINED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 302)
    type___ParentalStatusType = ParentalStatusType
    def __init__(self,) -> None: ...

type___ParentalStatusTypeEnum = ParentalStatusTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionOrAdjustmentLagBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionOrAdjustmentLagBucketValue = typing___NewType(
        "ConversionOrAdjustmentLagBucketValue", builtin___int
    )
    type___ConversionOrAdjustmentLagBucketValue = ConversionOrAdjustmentLagBucketValue
    ConversionOrAdjustmentLagBucket: _ConversionOrAdjustmentLagBucket
    class _ConversionOrAdjustmentLagBucket(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 0
        )
        UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 1
        )
        CONVERSION_LESS_THAN_ONE_DAY = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 2
        )
        CONVERSION_ONE_TO_TWO_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 3
        )
        CONVERSION_TWO_TO_THREE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 4
        )
        CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 5
        )
        CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 6
        )
        CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 7
        )
        CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 8
        )
        CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 9
        )
        CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 10
        )
        CONVERSION_NINE_TO_TEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 11
        )
        CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 12
        )
        CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 13
        )
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 14
        )
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 15
        )
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 16
        )
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 17
        )
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 18
        )
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 19
        )
        CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 20
        )
        ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 21
        )
        ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 22
        )
        ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 23
        )
        ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 24
        )
        ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 25
        )
        ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 26
        )
        ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 27
        )
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 28
        )
        ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 29
        )
        ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 30
        )
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 31
        )
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 32
        )
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 33
        )
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 34
        )
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 35
        )
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 36
        )
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 37
        )
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 38
        )
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 39
        )
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 40
        )
        CONVERSION_UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 41
        )
        ADJUSTMENT_UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 42
        )
    UNSPECIFIED = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 0
    )
    UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 1
    )
    CONVERSION_LESS_THAN_ONE_DAY = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 2
    )
    CONVERSION_ONE_TO_TWO_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 3
    )
    CONVERSION_TWO_TO_THREE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 4
    )
    CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 5
    )
    CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 6
    )
    CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 7
    )
    CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 8
    )
    CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 9
    )
    CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 10
    )
    CONVERSION_NINE_TO_TEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 11
    )
    CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 12
    )
    CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 13
    )
    CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 14
    )
    CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 15
    )
    CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 16
    )
    CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 17
    )
    CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 18
    )
    CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 19
    )
    CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 20
    )
    ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 21
    )
    ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 22
    )
    ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 23
    )
    ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 24
    )
    ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 25
    )
    ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 26
    )
    ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 27
    )
    ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 28
    )
    ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 29
    )
    ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 30
    )
    ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 31
    )
    ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 32
    )
    ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 33
    )
    ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 34
    )
    ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 35
    )
    ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 36
    )
    ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 37
    )
    ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 38
    )
    ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 39
    )
    ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 40
    )
    CONVERSION_UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 41
    )
    ADJUSTMENT_UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 42
    )
    type___ConversionOrAdjustmentLagBucket = ConversionOrAdjustmentLagBucket
    def __init__(self,) -> None: ...

type___ConversionOrAdjustmentLagBucketEnum = ConversionOrAdjustmentLagBucketEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.combined_audience_status_pb2 import (
    CombinedAudienceStatusEnum as google___ads___googleads___v6___enums___combined_audience_status_pb2___CombinedAudienceStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CombinedAudience(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    status: google___ads___googleads___v6___enums___combined_audience_status_pb2___CombinedAudienceStatusEnum.CombinedAudienceStatusValue = ...
    name: typing___Text = ...
    description: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___combined_audience_status_pb2___CombinedAudienceStatusEnum.CombinedAudienceStatusValue
        ] = None,
        name: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "description",
            b"description",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

type___CombinedAudience = CombinedAudience



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateJobStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MutateJobStatusValue = typing___NewType("MutateJobStatusValue", builtin___int)
    type___MutateJobStatusValue = MutateJobStatusValue
    MutateJobStatus: _MutateJobStatus
    class _MutateJobStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MutateJobStatusEnum.MutateJobStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 0)
        UNKNOWN = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 1)
        PENDING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 2)
        RUNNING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 3)
        DONE = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 4)
    UNSPECIFIED = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 0)
    UNKNOWN = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 1)
    PENDING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 2)
    RUNNING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 3)
    DONE = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 4)
    type___MutateJobStatus = MutateJobStatus
    def __init__(self,) -> None: ...

type___MutateJobStatusEnum = MutateJobStatusEnum



from typing import Any

class CustomerLabelServiceStub:
    GetCustomerLabel: Any = ...
    MutateCustomerLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerLabelServiceServicer:
    def GetCustomerLabel(self, request: Any, context: Any) -> None: ...
    def MutateCustomerLabels(self, request: Any, context: Any) -> None: ...

def add_CustomerLabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ImageErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ImageErrorValue = typing___NewType("ImageErrorValue", builtin___int)
    type___ImageErrorValue = ImageErrorValue
    ImageError: _ImageError
    class _ImageError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ImageErrorEnum.ImageErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ImageErrorEnum.ImageErrorValue, 0)
        UNKNOWN = typing___cast(ImageErrorEnum.ImageErrorValue, 1)
        INVALID_IMAGE = typing___cast(ImageErrorEnum.ImageErrorValue, 2)
        STORAGE_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 3)
        BAD_REQUEST = typing___cast(ImageErrorEnum.ImageErrorValue, 4)
        UNEXPECTED_SIZE = typing___cast(ImageErrorEnum.ImageErrorValue, 5)
        ANIMATED_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 6)
        ANIMATION_TOO_LONG = typing___cast(ImageErrorEnum.ImageErrorValue, 7)
        SERVER_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 8)
        CMYK_JPEG_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 9)
        FLASH_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 10)
        FLASH_WITHOUT_CLICKTAG = typing___cast(ImageErrorEnum.ImageErrorValue, 11)
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG = typing___cast(
            ImageErrorEnum.ImageErrorValue, 12
        )
        ANIMATED_VISUAL_EFFECT = typing___cast(ImageErrorEnum.ImageErrorValue, 13)
        FLASH_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 14)
        LAYOUT_PROBLEM = typing___cast(ImageErrorEnum.ImageErrorValue, 15)
        PROBLEM_READING_IMAGE_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 16)
        ERROR_STORING_IMAGE = typing___cast(ImageErrorEnum.ImageErrorValue, 17)
        ASPECT_RATIO_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 18)
        FLASH_HAS_NETWORK_OBJECTS = typing___cast(ImageErrorEnum.ImageErrorValue, 19)
        FLASH_HAS_NETWORK_METHODS = typing___cast(ImageErrorEnum.ImageErrorValue, 20)
        FLASH_HAS_URL = typing___cast(ImageErrorEnum.ImageErrorValue, 21)
        FLASH_HAS_MOUSE_TRACKING = typing___cast(ImageErrorEnum.ImageErrorValue, 22)
        FLASH_HAS_RANDOM_NUM = typing___cast(ImageErrorEnum.ImageErrorValue, 23)
        FLASH_SELF_TARGETS = typing___cast(ImageErrorEnum.ImageErrorValue, 24)
        FLASH_BAD_GETURL_TARGET = typing___cast(ImageErrorEnum.ImageErrorValue, 25)
        FLASH_VERSION_NOT_SUPPORTED = typing___cast(ImageErrorEnum.ImageErrorValue, 26)
        FLASH_WITHOUT_HARD_CODED_CLICK_URL = typing___cast(
            ImageErrorEnum.ImageErrorValue, 27
        )
        INVALID_FLASH_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 28)
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH = typing___cast(
            ImageErrorEnum.ImageErrorValue, 29
        )
        FLASH_ACCESSES_NETWORK_RESOURCES = typing___cast(
            ImageErrorEnum.ImageErrorValue, 30
        )
        FLASH_EXTERNAL_JS_CALL = typing___cast(ImageErrorEnum.ImageErrorValue, 31)
        FLASH_EXTERNAL_FS_CALL = typing___cast(ImageErrorEnum.ImageErrorValue, 32)
        FILE_TOO_LARGE = typing___cast(ImageErrorEnum.ImageErrorValue, 33)
        IMAGE_DATA_TOO_LARGE = typing___cast(ImageErrorEnum.ImageErrorValue, 34)
        IMAGE_PROCESSING_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 35)
        IMAGE_TOO_SMALL = typing___cast(ImageErrorEnum.ImageErrorValue, 36)
        INVALID_INPUT = typing___cast(ImageErrorEnum.ImageErrorValue, 37)
        PROBLEM_READING_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 38)
        IMAGE_CONSTRAINTS_VIOLATED = typing___cast(ImageErrorEnum.ImageErrorValue, 39)
    UNSPECIFIED = typing___cast(ImageErrorEnum.ImageErrorValue, 0)
    UNKNOWN = typing___cast(ImageErrorEnum.ImageErrorValue, 1)
    INVALID_IMAGE = typing___cast(ImageErrorEnum.ImageErrorValue, 2)
    STORAGE_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 3)
    BAD_REQUEST = typing___cast(ImageErrorEnum.ImageErrorValue, 4)
    UNEXPECTED_SIZE = typing___cast(ImageErrorEnum.ImageErrorValue, 5)
    ANIMATED_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 6)
    ANIMATION_TOO_LONG = typing___cast(ImageErrorEnum.ImageErrorValue, 7)
    SERVER_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 8)
    CMYK_JPEG_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 9)
    FLASH_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 10)
    FLASH_WITHOUT_CLICKTAG = typing___cast(ImageErrorEnum.ImageErrorValue, 11)
    FLASH_ERROR_AFTER_FIXING_CLICK_TAG = typing___cast(
        ImageErrorEnum.ImageErrorValue, 12
    )
    ANIMATED_VISUAL_EFFECT = typing___cast(ImageErrorEnum.ImageErrorValue, 13)
    FLASH_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 14)
    LAYOUT_PROBLEM = typing___cast(ImageErrorEnum.ImageErrorValue, 15)
    PROBLEM_READING_IMAGE_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 16)
    ERROR_STORING_IMAGE = typing___cast(ImageErrorEnum.ImageErrorValue, 17)
    ASPECT_RATIO_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageErrorValue, 18)
    FLASH_HAS_NETWORK_OBJECTS = typing___cast(ImageErrorEnum.ImageErrorValue, 19)
    FLASH_HAS_NETWORK_METHODS = typing___cast(ImageErrorEnum.ImageErrorValue, 20)
    FLASH_HAS_URL = typing___cast(ImageErrorEnum.ImageErrorValue, 21)
    FLASH_HAS_MOUSE_TRACKING = typing___cast(ImageErrorEnum.ImageErrorValue, 22)
    FLASH_HAS_RANDOM_NUM = typing___cast(ImageErrorEnum.ImageErrorValue, 23)
    FLASH_SELF_TARGETS = typing___cast(ImageErrorEnum.ImageErrorValue, 24)
    FLASH_BAD_GETURL_TARGET = typing___cast(ImageErrorEnum.ImageErrorValue, 25)
    FLASH_VERSION_NOT_SUPPORTED = typing___cast(ImageErrorEnum.ImageErrorValue, 26)
    FLASH_WITHOUT_HARD_CODED_CLICK_URL = typing___cast(
        ImageErrorEnum.ImageErrorValue, 27
    )
    INVALID_FLASH_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 28)
    FAILED_TO_FIX_CLICK_TAG_IN_FLASH = typing___cast(ImageErrorEnum.ImageErrorValue, 29)
    FLASH_ACCESSES_NETWORK_RESOURCES = typing___cast(ImageErrorEnum.ImageErrorValue, 30)
    FLASH_EXTERNAL_JS_CALL = typing___cast(ImageErrorEnum.ImageErrorValue, 31)
    FLASH_EXTERNAL_FS_CALL = typing___cast(ImageErrorEnum.ImageErrorValue, 32)
    FILE_TOO_LARGE = typing___cast(ImageErrorEnum.ImageErrorValue, 33)
    IMAGE_DATA_TOO_LARGE = typing___cast(ImageErrorEnum.ImageErrorValue, 34)
    IMAGE_PROCESSING_ERROR = typing___cast(ImageErrorEnum.ImageErrorValue, 35)
    IMAGE_TOO_SMALL = typing___cast(ImageErrorEnum.ImageErrorValue, 36)
    INVALID_INPUT = typing___cast(ImageErrorEnum.ImageErrorValue, 37)
    PROBLEM_READING_FILE = typing___cast(ImageErrorEnum.ImageErrorValue, 38)
    IMAGE_CONSTRAINTS_VIOLATED = typing___cast(ImageErrorEnum.ImageErrorValue, 39)
    type___ImageError = ImageError
    def __init__(self,) -> None: ...

type___ImageErrorEnum = ImageErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.resources.ad_group_extension_setting_pb2 import (
    AdGroupExtensionSetting as google___ads___googleads___v5___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetAdGroupExtensionSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetAdGroupExtensionSettingRequest = GetAdGroupExtensionSettingRequest

class MutateAdGroupExtensionSettingsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___AdGroupExtensionSettingOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___AdGroupExtensionSettingOperation]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___MutateAdGroupExtensionSettingsRequest = MutateAdGroupExtensionSettingsRequest

class AdGroupExtensionSettingOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove: typing___Text = ...
    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v5___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting: ...
    @property
    def update(
        self,
    ) -> google___ads___googleads___v5___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting: ...
    def __init__(
        self,
        *,
        update_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        create: typing___Optional[
            google___ads___googleads___v5___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting
        ] = None,
        update: typing___Optional[
            google___ads___googleads___v5___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting
        ] = None,
        remove: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "update", "remove"]: ...

type___AdGroupExtensionSettingOperation = AdGroupExtensionSettingOperation

class MutateAdGroupExtensionSettingsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateAdGroupExtensionSettingResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        results: typing___Optional[
            typing___Iterable[type___MutateAdGroupExtensionSettingResult]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___MutateAdGroupExtensionSettingsResponse = MutateAdGroupExtensionSettingsResponse

class MutateAdGroupExtensionSettingResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateAdGroupExtensionSettingResult = MutateAdGroupExtensionSettingResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DisplayUploadProductTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DisplayUploadProductTypeValue = typing___NewType(
        "DisplayUploadProductTypeValue", builtin___int
    )
    type___DisplayUploadProductTypeValue = DisplayUploadProductTypeValue
    DisplayUploadProductType: _DisplayUploadProductType
    class _DisplayUploadProductType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 0
        )
        UNKNOWN = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 1
        )
        HTML5_UPLOAD_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 2
        )
        DYNAMIC_HTML5_EDUCATION_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 3
        )
        DYNAMIC_HTML5_FLIGHT_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 4
        )
        DYNAMIC_HTML5_HOTEL_RENTAL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 5
        )
        DYNAMIC_HTML5_JOB_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 6
        )
        DYNAMIC_HTML5_LOCAL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 7
        )
        DYNAMIC_HTML5_REAL_ESTATE_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 8
        )
        DYNAMIC_HTML5_CUSTOM_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 9
        )
        DYNAMIC_HTML5_TRAVEL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 10
        )
        DYNAMIC_HTML5_HOTEL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 11
        )
    UNSPECIFIED = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 0
    )
    UNKNOWN = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 1
    )
    HTML5_UPLOAD_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 2
    )
    DYNAMIC_HTML5_EDUCATION_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 3
    )
    DYNAMIC_HTML5_FLIGHT_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 4
    )
    DYNAMIC_HTML5_HOTEL_RENTAL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 5
    )
    DYNAMIC_HTML5_JOB_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 6
    )
    DYNAMIC_HTML5_LOCAL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 7
    )
    DYNAMIC_HTML5_REAL_ESTATE_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 8
    )
    DYNAMIC_HTML5_CUSTOM_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 9
    )
    DYNAMIC_HTML5_TRAVEL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 10
    )
    DYNAMIC_HTML5_HOTEL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 11
    )
    type___DisplayUploadProductType = DisplayUploadProductType
    def __init__(self,) -> None: ...

type___DisplayUploadProductTypeEnum = DisplayUploadProductTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperimentErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignExperimentErrorValue = typing___NewType(
        "CampaignExperimentErrorValue", builtin___int
    )
    type___CampaignExperimentErrorValue = CampaignExperimentErrorValue
    CampaignExperimentError: _CampaignExperimentError
    class _CampaignExperimentError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 1
        )
        DUPLICATE_NAME = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 2
        )
        INVALID_TRANSITION = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 3
        )
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 4
        )
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 5
        )
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 6
        )
        CUSTOMER_CANNOT_CREATE_EXPERIMENT = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 7
        )
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 8
        )
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 9
        )
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 10
        )
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = typing___cast(
            CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 11
        )
    UNSPECIFIED = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 0
    )
    UNKNOWN = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 1)
    DUPLICATE_NAME = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 2
    )
    INVALID_TRANSITION = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 3
    )
    CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 4
    )
    CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 5
    )
    CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 6
    )
    CUSTOMER_CANNOT_CREATE_EXPERIMENT = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 7
    )
    CAMPAIGN_CANNOT_CREATE_EXPERIMENT = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 8
    )
    EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 9
    )
    EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 10
    )
    CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = typing___cast(
        CampaignExperimentErrorEnum.CampaignExperimentErrorValue, 11
    )
    type___CampaignExperimentError = CampaignExperimentError
    def __init__(self,) -> None: ...

type___CampaignExperimentErrorEnum = CampaignExperimentErrorEnum



from typing import Any, Sequence, Union

from google.protobuf.message import Message

class ResourceName:
    @classmethod
    def format_composite(cls, *arg: str) -> str: ...

def get_nested_attr(obj: Any, attr: str, *args: Any) -> Any: ...
def set_nested_message_field(
    message: Message, field_path: Union[str, Sequence[str]], value: Any
) -> None: ...
def convert_upper_case_to_snake_case(string: str) -> str: ...
def convert_snake_case_to_upper_case(string: str) -> str: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.resources.account_link_pb2 import (
    AccountLink as google___ads___googleads___v5___resources___account_link_pb2___AccountLink,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetAccountLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetAccountLinkRequest = GetAccountLinkRequest

class CreateAccountLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def account_link(
        self,
    ) -> google___ads___googleads___v5___resources___account_link_pb2___AccountLink: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        account_link: typing___Optional[
            google___ads___googleads___v5___resources___account_link_pb2___AccountLink
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["account_link", b"account_link"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_link", b"account_link", "customer_id", b"customer_id"
        ],
    ) -> None: ...

type___CreateAccountLinkRequest = CreateAccountLinkRequest

class CreateAccountLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___CreateAccountLinkResponse = CreateAccountLinkResponse

class MutateAccountLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def operation(self) -> type___AccountLinkOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operation: typing___Optional[type___AccountLinkOperation] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["operation", b"operation"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operation",
            b"operation",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___MutateAccountLinkRequest = MutateAccountLinkRequest

class AccountLinkOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove: typing___Text = ...
    def __init__(self, *, remove: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["remove"]: ...

type___AccountLinkOperation = AccountLinkOperation

class MutateAccountLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def result(self) -> type___MutateAccountLinkResult: ...
    def __init__(
        self, *, result: typing___Optional[type___MutateAccountLinkResult] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> None: ...

type___MutateAccountLinkResponse = MutateAccountLinkResponse

class MutateAccountLinkResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateAccountLinkResult = MutateAccountLinkResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListOperationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ListOperationErrorValue = typing___NewType("ListOperationErrorValue", builtin___int)
    type___ListOperationErrorValue = ListOperationErrorValue
    ListOperationError: _ListOperationError
    class _ListOperationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ListOperationErrorEnum.ListOperationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ListOperationErrorEnum.ListOperationErrorValue, 0)
        UNKNOWN = typing___cast(ListOperationErrorEnum.ListOperationErrorValue, 1)
        REQUIRED_FIELD_MISSING = typing___cast(
            ListOperationErrorEnum.ListOperationErrorValue, 7
        )
        DUPLICATE_VALUES = typing___cast(
            ListOperationErrorEnum.ListOperationErrorValue, 8
        )
    UNSPECIFIED = typing___cast(ListOperationErrorEnum.ListOperationErrorValue, 0)
    UNKNOWN = typing___cast(ListOperationErrorEnum.ListOperationErrorValue, 1)
    REQUIRED_FIELD_MISSING = typing___cast(
        ListOperationErrorEnum.ListOperationErrorValue, 7
    )
    DUPLICATE_VALUES = typing___cast(ListOperationErrorEnum.ListOperationErrorValue, 8)
    type___ListOperationError = ListOperationError
    def __init__(self,) -> None: ...

type___ListOperationErrorEnum = ListOperationErrorEnum



from typing import Any, Optional

class SharedCriterionServiceStub:
    GetSharedCriterion: Any = ...
    MutateSharedCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SharedCriterionServiceServicer:
    def GetSharedCriterion(self, request: Any, context: Any) -> None: ...
    def MutateSharedCriteria(self, request: Any, context: Any) -> None: ...

def add_SharedCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class SharedCriterionService:
    @staticmethod
    def GetSharedCriterion(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateSharedCriteria(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeClientTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeClientTypeValue = typing___NewType("ChangeClientTypeValue", builtin___int)
    type___ChangeClientTypeValue = ChangeClientTypeValue
    ChangeClientType: _ChangeClientType
    class _ChangeClientType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeClientTypeEnum.ChangeClientTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 0)
        UNKNOWN = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 1)
        GOOGLE_ADS_WEB_CLIENT = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 2
        )
        GOOGLE_ADS_AUTOMATED_RULE = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 3
        )
        GOOGLE_ADS_SCRIPTS = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 4
        )
        GOOGLE_ADS_BULK_UPLOAD = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 5
        )
        GOOGLE_ADS_API = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 6)
        GOOGLE_ADS_EDITOR = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 7)
        GOOGLE_ADS_MOBILE_APP = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 8
        )
        GOOGLE_ADS_RECOMMENDATIONS = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 9
        )
        SEARCH_ADS_360_SYNC = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 10
        )
        SEARCH_ADS_360_POST = typing___cast(
            ChangeClientTypeEnum.ChangeClientTypeValue, 11
        )
        INTERNAL_TOOL = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 12)
        OTHER = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 13)
    UNSPECIFIED = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 0)
    UNKNOWN = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 1)
    GOOGLE_ADS_WEB_CLIENT = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 2)
    GOOGLE_ADS_AUTOMATED_RULE = typing___cast(
        ChangeClientTypeEnum.ChangeClientTypeValue, 3
    )
    GOOGLE_ADS_SCRIPTS = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 4)
    GOOGLE_ADS_BULK_UPLOAD = typing___cast(
        ChangeClientTypeEnum.ChangeClientTypeValue, 5
    )
    GOOGLE_ADS_API = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 6)
    GOOGLE_ADS_EDITOR = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 7)
    GOOGLE_ADS_MOBILE_APP = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 8)
    GOOGLE_ADS_RECOMMENDATIONS = typing___cast(
        ChangeClientTypeEnum.ChangeClientTypeValue, 9
    )
    SEARCH_ADS_360_SYNC = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 10)
    SEARCH_ADS_360_POST = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 11)
    INTERNAL_TOOL = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 12)
    OTHER = typing___cast(ChangeClientTypeEnum.ChangeClientTypeValue, 13)
    type___ChangeClientType = ChangeClientType
    def __init__(self,) -> None: ...

type___ChangeClientTypeEnum = ChangeClientTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserAddressInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def hashed_first_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def hashed_last_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def city(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def state(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        hashed_first_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        hashed_last_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        city: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        state: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        postal_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> None: ...

type___OfflineUserAddressInfo = OfflineUserAddressInfo

class UserIdentifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def hashed_email(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def hashed_phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def mobile_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def third_party_user_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def address_info(self) -> type___OfflineUserAddressInfo: ...
    def __init__(
        self,
        *,
        hashed_email: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        hashed_phone_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        mobile_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        third_party_user_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        address_info: typing___Optional[type___OfflineUserAddressInfo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["identifier", b"identifier"]
    ) -> typing_extensions___Literal[
        "hashed_email",
        "hashed_phone_number",
        "mobile_id",
        "third_party_user_id",
        "address_info",
    ]: ...

type___UserIdentifier = UserIdentifier

class TransactionAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def transaction_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def transaction_amount_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def order_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def store_attribute(self) -> type___StoreAttribute: ...
    @property
    def custom_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        transaction_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        transaction_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        order_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        store_attribute: typing___Optional[type___StoreAttribute] = None,
        custom_value: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> None: ...

type___TransactionAttribute = TransactionAttribute

class StoreAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def store_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        store_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["store_code", b"store_code"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["store_code", b"store_code"]
    ) -> None: ...

type___StoreAttribute = StoreAttribute

class UserData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def user_identifiers(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserIdentifier
    ]: ...
    @property
    def transaction_attribute(self) -> type___TransactionAttribute: ...
    def __init__(
        self,
        *,
        user_identifiers: typing___Optional[
            typing___Iterable[type___UserIdentifier]
        ] = None,
        transaction_attribute: typing___Optional[type___TransactionAttribute] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "transaction_attribute", b"transaction_attribute"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_identifiers",
            b"user_identifiers",
        ],
    ) -> None: ...

type___UserData = UserData

class CustomerMatchUserListMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def user_list(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        user_list: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["user_list", b"user_list"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["user_list", b"user_list"]
    ) -> None: ...

type___CustomerMatchUserListMetadata = CustomerMatchUserListMetadata

class StoreSalesMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def loyalty_fraction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def transaction_upload_fraction(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def custom_key(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def third_party_metadata(self) -> type___StoreSalesThirdPartyMetadata: ...
    def __init__(
        self,
        *,
        loyalty_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        transaction_upload_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        custom_key: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        third_party_metadata: typing___Optional[
            type___StoreSalesThirdPartyMetadata
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> None: ...

type___StoreSalesMetadata = StoreSalesMetadata

class StoreSalesThirdPartyMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def advertiser_upload_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def valid_transaction_fraction(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def partner_match_fraction(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def partner_upload_fraction(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def bridge_map_version_id(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def partner_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        advertiser_upload_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        valid_transaction_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        partner_match_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        partner_upload_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        bridge_map_version_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        partner_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> None: ...

type___StoreSalesThirdPartyMetadata = StoreSalesThirdPartyMetadata



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DistanceBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DistanceBucketValue = typing___NewType("DistanceBucketValue", builtin___int)
    type___DistanceBucketValue = DistanceBucketValue
    DistanceBucket: _DistanceBucket
    class _DistanceBucket(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DistanceBucketEnum.DistanceBucketValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DistanceBucketEnum.DistanceBucketValue, 0)
        UNKNOWN = typing___cast(DistanceBucketEnum.DistanceBucketValue, 1)
        WITHIN_700M = typing___cast(DistanceBucketEnum.DistanceBucketValue, 2)
        WITHIN_1KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 3)
        WITHIN_5KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 4)
        WITHIN_10KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 5)
        WITHIN_15KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 6)
        WITHIN_20KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 7)
        WITHIN_25KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 8)
        WITHIN_30KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 9)
        WITHIN_35KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 10)
        WITHIN_40KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 11)
        WITHIN_45KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 12)
        WITHIN_50KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 13)
        WITHIN_55KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 14)
        WITHIN_60KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 15)
        WITHIN_65KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 16)
        BEYOND_65KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 17)
        WITHIN_0_7MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 18)
        WITHIN_1MILE = typing___cast(DistanceBucketEnum.DistanceBucketValue, 19)
        WITHIN_5MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 20)
        WITHIN_10MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 21)
        WITHIN_15MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 22)
        WITHIN_20MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 23)
        WITHIN_25MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 24)
        WITHIN_30MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 25)
        WITHIN_35MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 26)
        WITHIN_40MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 27)
        BEYOND_40MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 28)
    UNSPECIFIED = typing___cast(DistanceBucketEnum.DistanceBucketValue, 0)
    UNKNOWN = typing___cast(DistanceBucketEnum.DistanceBucketValue, 1)
    WITHIN_700M = typing___cast(DistanceBucketEnum.DistanceBucketValue, 2)
    WITHIN_1KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 3)
    WITHIN_5KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 4)
    WITHIN_10KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 5)
    WITHIN_15KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 6)
    WITHIN_20KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 7)
    WITHIN_25KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 8)
    WITHIN_30KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 9)
    WITHIN_35KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 10)
    WITHIN_40KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 11)
    WITHIN_45KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 12)
    WITHIN_50KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 13)
    WITHIN_55KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 14)
    WITHIN_60KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 15)
    WITHIN_65KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 16)
    BEYOND_65KM = typing___cast(DistanceBucketEnum.DistanceBucketValue, 17)
    WITHIN_0_7MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 18)
    WITHIN_1MILE = typing___cast(DistanceBucketEnum.DistanceBucketValue, 19)
    WITHIN_5MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 20)
    WITHIN_10MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 21)
    WITHIN_15MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 22)
    WITHIN_20MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 23)
    WITHIN_25MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 24)
    WITHIN_30MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 25)
    WITHIN_35MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 26)
    WITHIN_40MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 27)
    BEYOND_40MILES = typing___cast(DistanceBucketEnum.DistanceBucketValue, 28)
    type___DistanceBucket = DistanceBucket
    def __init__(self,) -> None: ...

type___DistanceBucketEnum = DistanceBucketEnum



from typing import Any

class FeedMappingServiceStub:
    GetFeedMapping: Any = ...
    MutateFeedMappings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedMappingServiceServicer:
    def GetFeedMapping(self, request: Any, context: Any) -> None: ...
    def MutateFeedMappings(self, request: Any, context: Any) -> None: ...

def add_FeedMappingServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class CampaignFeedServiceStub:
    GetCampaignFeed: Any = ...
    MutateCampaignFeeds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignFeedServiceServicer:
    def GetCampaignFeed(self, request: Any, context: Any) -> None: ...
    def MutateCampaignFeeds(self, request: Any, context: Any) -> None: ...

def add_CampaignFeedServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class PaymentsAccountServiceStub:
    ListPaymentsAccounts: Any = ...
    def __init__(self, channel: Any) -> None: ...

class PaymentsAccountServiceServicer:
    def ListPaymentsAccounts(self, request: Any, context: Any) -> None: ...

def add_PaymentsAccountServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TrackingCodeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TrackingCodeTypeValue = typing___NewType("TrackingCodeTypeValue", builtin___int)
    type___TrackingCodeTypeValue = TrackingCodeTypeValue
    TrackingCodeType: _TrackingCodeType
    class _TrackingCodeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TrackingCodeTypeEnum.TrackingCodeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 0)
        UNKNOWN = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 1)
        WEBPAGE = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 2)
        WEBPAGE_ONCLICK = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 3)
        CLICK_TO_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 4)
        WEBSITE_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 5)
    UNSPECIFIED = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 0)
    UNKNOWN = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 1)
    WEBPAGE = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 2)
    WEBPAGE_ONCLICK = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 3)
    CLICK_TO_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 4)
    WEBSITE_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 5)
    type___TrackingCodeType = TrackingCodeType
    def __init__(self,) -> None: ...

type___TrackingCodeTypeEnum = TrackingCodeTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MatchingFunctionOperatorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MatchingFunctionOperatorValue = typing___NewType(
        "MatchingFunctionOperatorValue", builtin___int
    )
    type___MatchingFunctionOperatorValue = MatchingFunctionOperatorValue
    MatchingFunctionOperator: _MatchingFunctionOperator
    class _MatchingFunctionOperator(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 0
        )
        UNKNOWN = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 1
        )
        IN = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 2
        )
        IDENTITY = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 3
        )
        EQUALS = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 4
        )
        AND = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 5
        )
        CONTAINS_ANY = typing___cast(
            MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 6
        )
    UNSPECIFIED = typing___cast(
        MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 0
    )
    UNKNOWN = typing___cast(
        MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 1
    )
    IN = typing___cast(MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 2)
    IDENTITY = typing___cast(
        MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 3
    )
    EQUALS = typing___cast(
        MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 4
    )
    AND = typing___cast(MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 5)
    CONTAINS_ANY = typing___cast(
        MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue, 6
    )
    type___MatchingFunctionOperator = MatchingFunctionOperator
    def __init__(self,) -> None: ...

type___MatchingFunctionOperatorEnum = MatchingFunctionOperatorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FrequencyCapLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FrequencyCapLevelValue = typing___NewType("FrequencyCapLevelValue", builtin___int)
    type___FrequencyCapLevelValue = FrequencyCapLevelValue
    FrequencyCapLevel: _FrequencyCapLevel
    class _FrequencyCapLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FrequencyCapLevelEnum.FrequencyCapLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 0)
        UNKNOWN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 1)
        AD_GROUP_AD = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 2)
        AD_GROUP = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 3)
        CAMPAIGN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 4)
    UNSPECIFIED = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 0)
    UNKNOWN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 1)
    AD_GROUP_AD = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 2)
    AD_GROUP = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 3)
    CAMPAIGN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 4)
    type___FrequencyCapLevel = FrequencyCapLevel
    def __init__(self,) -> None: ...

type___FrequencyCapLevelEnum = FrequencyCapLevelEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Value(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    boolean_value: builtin___bool = ...
    int64_value: builtin___int = ...
    float_value: builtin___float = ...
    double_value: builtin___float = ...
    string_value: typing___Text = ...
    def __init__(
        self,
        *,
        boolean_value: typing___Optional[builtin___bool] = None,
        int64_value: typing___Optional[builtin___int] = None,
        float_value: typing___Optional[builtin___float] = None,
        double_value: typing___Optional[builtin___float] = None,
        string_value: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["value", b"value"]
    ) -> typing_extensions___Literal[
        "boolean_value", "int64_value", "float_value", "double_value", "string_value"
    ]: ...

type___Value = Value



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OptimizationGoalTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OptimizationGoalTypeValue = typing___NewType(
        "OptimizationGoalTypeValue", builtin___int
    )
    type___OptimizationGoalTypeValue = OptimizationGoalTypeValue
    OptimizationGoalType: _OptimizationGoalType
    class _OptimizationGoalType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 0
        )
        UNKNOWN = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 1)
        CALL_CLICKS = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 2
        )
        DRIVING_DIRECTIONS = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 3
        )
    UNSPECIFIED = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 0)
    UNKNOWN = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 1)
    CALL_CLICKS = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 2)
    DRIVING_DIRECTIONS = typing___cast(
        OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 3
    )
    type___OptimizationGoalType = OptimizationGoalType
    def __init__(self,) -> None: ...

type___OptimizationGoalTypeEnum = OptimizationGoalTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerMatchUploadKeyTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerMatchUploadKeyTypeValue = typing___NewType(
        "CustomerMatchUploadKeyTypeValue", builtin___int
    )
    type___CustomerMatchUploadKeyTypeValue = CustomerMatchUploadKeyTypeValue
    CustomerMatchUploadKeyType: _CustomerMatchUploadKeyType
    class _CustomerMatchUploadKeyType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 1
        )
        CONTACT_INFO = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 2
        )
        CRM_ID = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 3
        )
        MOBILE_ADVERTISING_ID = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 4
        )
    UNSPECIFIED = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 0
    )
    UNKNOWN = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 1
    )
    CONTACT_INFO = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 2
    )
    CRM_ID = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 3
    )
    MOBILE_ADVERTISING_ID = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 4
    )
    type___CustomerMatchUploadKeyType = CustomerMatchUploadKeyType
    def __init__(self,) -> None: ...

type___CustomerMatchUploadKeyTypeEnum = CustomerMatchUploadKeyTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BytesValue as google___protobuf___wrappers_pb2___BytesValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.media_type_pb2 import (
    MediaTypeEnum as google___ads___googleads___v3___enums___media_type_pb2___MediaTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v3___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaFile(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    type: google___ads___googleads___v3___enums___media_type_pb2___MediaTypeEnum.MediaTypeValue = ...
    mime_type: google___ads___googleads___v3___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def source_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def file_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def image(self) -> type___MediaImage: ...
    @property
    def media_bundle(self) -> type___MediaBundle: ...
    @property
    def audio(self) -> type___MediaAudio: ...
    @property
    def video(self) -> type___MediaVideo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___media_type_pb2___MediaTypeEnum.MediaTypeValue
        ] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v3___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        source_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        file_size: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        image: typing___Optional[type___MediaImage] = None,
        media_bundle: typing___Optional[type___MediaBundle] = None,
        audio: typing___Optional[type___MediaAudio] = None,
        video: typing___Optional[type___MediaVideo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "name",
            b"name",
            "source_url",
            b"source_url",
            "video",
            b"video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "source_url",
            b"source_url",
            "type",
            b"type",
            "video",
            b"video",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["mediatype", b"mediatype"]
    ) -> typing_extensions___Literal["image", "media_bundle", "audio", "video"]: ...

type___MediaFile = MediaFile

class MediaImage(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...
    def __init__(
        self,
        *,
        data: typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> None: ...

type___MediaImage = MediaImage

class MediaBundle(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...
    def __init__(
        self,
        *,
        data: typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> None: ...

type___MediaBundle = MediaBundle

class MediaAudio(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> None: ...

type___MediaAudio = MediaAudio

class MediaVideo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def youtube_video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def advertising_id_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def isci_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        youtube_video_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        advertising_id_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        isci_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...

type___MediaVideo = MediaVideo



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaFileErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaFileErrorValue = typing___NewType("MediaFileErrorValue", builtin___int)
    type___MediaFileErrorValue = MediaFileErrorValue
    MediaFileError: _MediaFileError
    class _MediaFileError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaFileErrorEnum.MediaFileErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 0)
        UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 1)
        CANNOT_CREATE_STANDARD_ICON = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 2
        )
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 3
        )
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 4
        )
        DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 5)
        EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 7
        )
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 8
        )
        INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 9)
        INVALID_MEDIA_SUB_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 10
        )
        INVALID_MEDIA_FILE_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 11
        )
        INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 12)
        INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 13)
        INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 14)
        MEDIA_FILE_FAILED_TRANSCODING = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 15
        )
        MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 17
        )
        NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 19
        )
        TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 20)
        UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 21)
        YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 22
        )
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 23
        )
        YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 24
        )
    UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 0)
    UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 1)
    CANNOT_CREATE_STANDARD_ICON = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 2
    )
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 3
    )
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 4
    )
    DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 5)
    EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 7
    )
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 8
    )
    INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 9)
    INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 10)
    INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 11)
    INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 12)
    INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 13)
    INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 14)
    MEDIA_FILE_FAILED_TRANSCODING = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 15
    )
    MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 17
    )
    NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 19
    )
    TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 20)
    UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 21)
    YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 22
    )
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 23
    )
    YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 24)
    type___MediaFileError = MediaFileError
    def __init__(self,) -> None: ...

type___MediaFileErrorEnum = MediaFileErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PlaceholderTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PlaceholderTypeValue = typing___NewType("PlaceholderTypeValue", builtin___int)
    type___PlaceholderTypeValue = PlaceholderTypeValue
    PlaceholderType: _PlaceholderType
    class _PlaceholderType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PlaceholderTypeEnum.PlaceholderTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 0)
        UNKNOWN = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 1)
        SITELINK = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 2)
        CALL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 3)
        APP = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 4)
        LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 5)
        AFFILIATE_LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 6)
        CALLOUT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 7)
        STRUCTURED_SNIPPET = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 8)
        MESSAGE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 9)
        PRICE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 10)
        PROMOTION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 11)
        AD_CUSTOMIZER = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 12)
        DYNAMIC_EDUCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 13)
        DYNAMIC_FLIGHT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 14)
        DYNAMIC_CUSTOM = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 15)
        DYNAMIC_HOTEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 16)
        DYNAMIC_REAL_ESTATE = typing___cast(
            PlaceholderTypeEnum.PlaceholderTypeValue, 17
        )
        DYNAMIC_TRAVEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 18)
        DYNAMIC_LOCAL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 19)
        DYNAMIC_JOB = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 20)
    UNSPECIFIED = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 0)
    UNKNOWN = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 1)
    SITELINK = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 2)
    CALL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 3)
    APP = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 4)
    LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 5)
    AFFILIATE_LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 6)
    CALLOUT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 7)
    STRUCTURED_SNIPPET = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 8)
    MESSAGE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 9)
    PRICE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 10)
    PROMOTION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 11)
    AD_CUSTOMIZER = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 12)
    DYNAMIC_EDUCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 13)
    DYNAMIC_FLIGHT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 14)
    DYNAMIC_CUSTOM = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 15)
    DYNAMIC_HOTEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 16)
    DYNAMIC_REAL_ESTATE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 17)
    DYNAMIC_TRAVEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 18)
    DYNAMIC_LOCAL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 19)
    DYNAMIC_JOB = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 20)
    type___PlaceholderType = PlaceholderType
    def __init__(self,) -> None: ...

type___PlaceholderTypeEnum = PlaceholderTypeEnum



from typing import Any

class RemarketingActionServiceStub:
    GetRemarketingAction: Any = ...
    MutateRemarketingActions: Any = ...
    def __init__(self, channel: Any) -> None: ...

class RemarketingActionServiceServicer:
    def GetRemarketingAction(self, request: Any, context: Any) -> None: ...
    def MutateRemarketingActions(self, request: Any, context: Any) -> None: ...

def add_RemarketingActionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExpandedLandingPageView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    expanded_final_url: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        expanded_final_url: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_expanded_final_url",
            b"_expanded_final_url",
            "expanded_final_url",
            b"expanded_final_url",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_expanded_final_url",
            b"_expanded_final_url",
            "expanded_final_url",
            b"expanded_final_url",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_expanded_final_url", b"_expanded_final_url"
        ],
    ) -> typing_extensions___Literal["expanded_final_url"]: ...

type___ExpandedLandingPageView = ExpandedLandingPageView



from typing import Any

class FeedPlaceholderViewServiceStub:
    GetFeedPlaceholderView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedPlaceholderViewServiceServicer:
    def GetFeedPlaceholderView(self, request: Any, context: Any) -> None: ...

def add_FeedPlaceholderViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class UserDataServiceStub:
    UploadUserData: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserDataServiceServicer:
    def UploadUserData(self, request: Any, context: Any) -> None: ...

def add_UserDataServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class InternalErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    InternalErrorValue = typing___NewType("InternalErrorValue", builtin___int)
    type___InternalErrorValue = InternalErrorValue
    InternalError: _InternalError
    class _InternalError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            InternalErrorEnum.InternalErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(InternalErrorEnum.InternalErrorValue, 0)
        UNKNOWN = typing___cast(InternalErrorEnum.InternalErrorValue, 1)
        INTERNAL_ERROR = typing___cast(InternalErrorEnum.InternalErrorValue, 2)
        ERROR_CODE_NOT_PUBLISHED = typing___cast(
            InternalErrorEnum.InternalErrorValue, 3
        )
        TRANSIENT_ERROR = typing___cast(InternalErrorEnum.InternalErrorValue, 4)
        DEADLINE_EXCEEDED = typing___cast(InternalErrorEnum.InternalErrorValue, 5)
    UNSPECIFIED = typing___cast(InternalErrorEnum.InternalErrorValue, 0)
    UNKNOWN = typing___cast(InternalErrorEnum.InternalErrorValue, 1)
    INTERNAL_ERROR = typing___cast(InternalErrorEnum.InternalErrorValue, 2)
    ERROR_CODE_NOT_PUBLISHED = typing___cast(InternalErrorEnum.InternalErrorValue, 3)
    TRANSIENT_ERROR = typing___cast(InternalErrorEnum.InternalErrorValue, 4)
    DEADLINE_EXCEEDED = typing___cast(InternalErrorEnum.InternalErrorValue, 5)
    type___InternalError = InternalError
    def __init__(self,) -> None: ...

type___InternalErrorEnum = InternalErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DomainCategory(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def category(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def domain(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def coverage_fraction(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def category_rank(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def has_children(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def recommended_cpc_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        category: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        language_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        domain: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        coverage_fraction: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        category_rank: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        has_children: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        recommended_cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___DomainCategory = DomainCategory



from typing import Any

class GoogleAdsFieldServiceStub:
    GetGoogleAdsField: Any = ...
    SearchGoogleAdsFields: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GoogleAdsFieldServiceServicer:
    def GetGoogleAdsField(self, request: Any, context: Any) -> None: ...
    def SearchGoogleAdsFields(self, request: Any, context: Any) -> None: ...

def add_GoogleAdsFieldServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
